@@ -6,7 +6,9 @@ import json
 
 from abc import abstractmethod
 from pathlib import Path
+import re
 from typing import Any, List, Optional, Union, final
+from packageurl import PackageURL  # type: ignore
 
 from hoppr_cyclonedx_models.cyclonedx_1_4 import Component
 
@@ -44,6 +46,30 @@ class BaseCollectorPlugin(HopprPlugin):
 
         return directory
 
+    @staticmethod
+    def check_purl_specified_url(purl: PackageURL, repo_url: str) -> Result:
+        """
+        Test if a repository_url specified as a purl qualifier is a mis-match with a given repo_url
+
+        If no repository_url is specified, repo_url is fine, no-mismatch, return False
+
+        Otherwise, considered a match if repo_url starts with the purl url (after trimming trailing
+        "/"s and URL scheme, if present)
+        """
+        purl_url = purl.qualifiers.get("repository_url")
+        if purl_url is None:
+            return Result.success()
+
+        trimmed_purl_url = re.sub(r"(ssh|file|https?)://", "", purl_url).rstrip("/")
+        trimmed_repo_url = re.sub(r"(ssh|file|https?)://", "", repo_url).rstrip("/")
+        if trimmed_repo_url.startswith(trimmed_purl_url):
+            return Result.success()
+
+        return Result.fail(
+            f"Purl-specified repository url ({purl.qualifiers.get('repository_url')}) "
+            + f"does not match current repo ({repo_url})."
+        )
+
 
 class SerialCollectorPlugin(BaseCollectorPlugin):
     """
