@@ -237,7 +237,9 @@ class HopprPlugin(ABC):
         """
         self._logger.close()
 
-    def run_command(self, command, password_list=None, cwd=None):
+    def run_command(
+        self, command, password_list=None, cwd=None
+    ) -> subprocess.CompletedProcess[bytes]:
         """
         Run a command and log any errors
         """
