@@ -41,8 +41,13 @@ class CollectDockerPlugin(SerialCollectorPlugin):
         Copy a component to the local collection directory structure
         """
         purl = PackageURL.from_string(comp.purl)
-        purl_id = purl.name + ":" + purl.version
-        source_url = os.path.join(repo_url, purl.namespace or "", purl_id)
+        docker_result = self.check_purl_specified_url(purl, repo_url)
+        if not docker_result.is_success():
+            return docker_result
+
+        source_url = os.path.join(
+            repo_url, purl.namespace or "", purl.name + ":" + purl.version
+        )
         source_url = re.sub(r"^https?://", "", source_url)
         if not source_url.startswith("docker://"):
             source_url = "docker://" + source_url
