@@ -41,6 +41,9 @@ class CollectGitPlugin(SerialCollectorPlugin):
         Collect git repository
         """
         purl = PackageURL.from_string(comp.purl)
+        git_result = self.check_purl_specified_url(purl, repo_url)
+        if not git_result.is_success():
+            return git_result
 
         self.get_logger().info(f"Copying git repository from {repo_url}")
 
@@ -49,13 +52,13 @@ class CollectGitPlugin(SerialCollectorPlugin):
             purl.type, repo_url, subdir=os.path.join(purl.namespace, purl.name)
         )
 
-        result = self.git_clone(target_dir, source_url, creds)
-        if not result.is_success():
-            return result
+        git_result = self.git_clone(target_dir, source_url, creds)
+        if not git_result.is_success():
+            return git_result
 
-        result = self.git_update(target_dir, purl.name)
-        if not result.is_success():
-            return result
+        git_result = self.git_update(target_dir, purl.name)
+        if not git_result.is_success():
+            return git_result
 
         return Result.success()
 
