@@ -36,6 +36,10 @@ class CollectRawPlugin(SerialCollectorPlugin):
         source_url = urlparse(repo_url)
 
         purl = PackageURL.from_string(comp.purl)
+        result = self.check_purl_specified_url(purl, repo_url)
+        if not result.is_success():
+            return result
+
         subdir = None
         if purl.namespace is not None:
             source_url = urlparse(urljoin(source_url.geturl() + "/", purl.namespace))
